@@ -17,12 +17,13 @@ REQUIREMENTS = {
                 "term.@id": ["resourceUseEnergyDepletionInputsProduction", "resourceUseEnergyDepletionDuringCycle"],
                 "term.units": "MJ",
                 "value": "> 0",
-                "inputs":
+                "inputs": [
                     {
                         "@type": "Input",
                         "term.name": "non-renewable\" energy terms only,\"",
                         "term.termType": ["fuel", "electricity"]
                     }
+                ]
             }
         ]
     }
@@ -66,10 +67,7 @@ def _valid_input(input: dict) -> bool:
     ]))
 
 
-def _indicator(value: float):
-    indicator = _new_indicator(TERM_ID, MODEL)
-    indicator["value"] = value
-    return indicator
+def _indicator(value: float): return _new_indicator(term=TERM_ID, model=MODEL, value=value)
 
 
 def _run(energy_resources_in_mj: list):
