@@ -1,4 +1,5 @@
 from hestia_earth.models.linkedImpactAssessment.utils import run_inputs_production
+from . import MODEL
 
 REQUIREMENTS = {
     "ImpactAssessment": {
@@ -37,4 +38,4 @@ RETURNS = {
 TERM_ID = 'resourceUseMineralsAndMetalsInputsProduction'
 
 
-def run(impact_assessment: dict): return run_inputs_production(impact_assessment, TERM_ID)
+def run(impact_assessment: dict): return run_inputs_production(impact_assessment, TERM_ID, MODEL)
