@@ -46,7 +46,7 @@ def _run(excreta_EF_input: float):
 def _should_run(cycle: dict):
     excreta_complete = _is_term_type_complete(cycle, TermTermType.EXCRETA)
     excreta_EF_input = get_excreta_inputs_with_factor(
-        cycle, f"{list(LOOKUPS.keys())[0]}.csv", excreta_convertion_func=total_excreta_tan, model=MODEL, term=TERM_ID
+        cycle, f"{list(LOOKUPS.keys())[0]}.csv", excreta_conversion_func=total_excreta_tan, model=MODEL, term=TERM_ID
     )
 
     logRequirements(cycle, model=MODEL, term=TERM_ID,
