@@ -1,10 +1,11 @@
-from hestia_earth.schema import NodeType, EmissionMethodTier
+from hestia_earth.schema import NodeType, EmissionMethodTier, TermTermType
+from hestia_earth.utils.lookup import download_lookup, lookup_term_ids, lookup_columns, column_name
 from hestia_earth.utils.lookup_utils import is_in_system_boundary
+from hestia_earth.utils.tools import flatten
 
 from hestia_earth.models.log import logRequirements, logShouldRun
 from hestia_earth.models.utils.emission import _new_emission
-from hestia_earth.models.utils.blank_node import _run_required
-from hestia_earth.models.utils.term import get_all_emission_terms
+from hestia_earth.models.utils.blank_node import _run_required, _run_model_required
 
 REQUIREMENTS = {
     "Cycle": {
@@ -18,22 +19,45 @@ RETURNS = {
     }]
 }
 LOOKUPS = {
-    "emission": "inHestiaDefaultSystemBoundary"
+    "emission": [
+        "term.id",
+        "inHestiaDefaultSystemBoundary",
+        "inputTermTypesAllowed",
+        "productTermIdsAllowed",
+        "productTermTypesAllowed",
+        "siteTypesAllowed",
+        "siteMeasurementIdsAllowed",
+        "typesAllowed"
+    ],
+    "emission-model-productTermIdsAllowed": "",
+    "emission-model-siteTypesAllowed": ""
 }
 MODEL = 'emissionNotRelevant'
 TIER = EmissionMethodTier.NOT_RELEVANT.value
 
 
 def _emission(term_id: str):
-    emission = _new_emission(term_id, MODEL)
-    emission['value'] = [0]
+    emission = _new_emission(term=term_id, model=MODEL, value=0)
     emission['methodTier'] = TIER
     return emission
 
 
-def _should_run_emission(cycle: dict):
+def _emission_ids():
+    return lookup_term_ids(download_lookup(f"{TermTermType.EMISSION.value}.csv"))
+
+
+def _model_ids(lookup_suffix: str):
+    return [
+        col for col in lookup_columns(download_lookup(f"emission-model-{lookup_suffix}.csv"))
+        if col != column_name('term.id')
+    ]
+
+
+def _should_run_emission(cycle: dict, model_ids: list):
     def run(term_id: str):
-        is_not_relevant = not _run_required(MODEL, term_id, cycle)
+        is_not_relevant = not _run_required(MODEL, term_id, cycle) or any([
+            not _run_model_required(model_id, term_id, cycle, skip_logs=True) for model_id in model_ids
+        ])
         in_system_boundary = is_in_system_boundary(term_id)
 
         should_run = all([is_not_relevant, in_system_boundary])
@@ -49,8 +73,9 @@ def _should_run_emission(cycle: dict):
 
 
 def _run(cycle: dict):
-    emissions = get_all_emission_terms()
-    term_ids = list(filter(_should_run_emission(cycle), emissions))
+    emissions = _emission_ids()
+    model_ids = list(set(flatten(map(_model_ids, ['productTermIdsAllowed', 'siteTypesAllowed']))))
+    term_ids = list(filter(_should_run_emission(cycle, model_ids), emissions))
     return list(map(_emission, term_ids))
 
 
