@@ -2,10 +2,10 @@ from hestia_earth.schema import TermTermType
 from hestia_earth.utils.lookup import extract_grouped_data_closest_date
 from hestia_earth.utils.model import filter_list_term_type
 from hestia_earth.utils.tools import non_empty_list, safe_parse_date, safe_parse_float
+from hestia_earth.utils.term import download_term
 
 from hestia_earth.models.log import logRequirements, logShouldRun
 from hestia_earth.models.utils.constant import Units
-from hestia_earth.models.utils.term import download_term
 from hestia_earth.models.utils.property import _new_property, node_has_no_property
 from hestia_earth.models.utils.product import convert_product_to_unit
 from hestia_earth.models.utils.animalProduct import FAO_LOOKUP_COLUMN, get_animalProduct_lookup_value
@@ -50,7 +50,7 @@ def _property(value: float):
     return prop
 
 
-def _product_value(product: dict, year: int, country_id: str):
+def _product_value(cycle: dict, product: dict, year: int, country_id: str):
     product_id = product.get('term', {}).get('@id')
     groupingFAO = get_animalProduct_lookup_value(MODEL, product_id, FAO_LOOKUP_COLUMN)
 
@@ -59,10 +59,14 @@ def _product_value(product: dict, year: int, country_id: str):
     # average_carcass_weight is in hg, divide by 10 to go back to kg
     kg_carcass_weight = average_carcass_weight / 10 if average_carcass_weight else None
 
-    kg_liveweight = convert_product_to_unit({
-        **product,
-        'value': [kg_carcass_weight]
-    }, Units.KG_LIVEWEIGHT) if kg_carcass_weight else None
+    kg_liveweight = convert_product_to_unit(
+        product={
+            **product,
+            'value': [kg_carcass_weight]
+        },
+        dest_unit=Units.KG_LIVEWEIGHT,
+        log_node=cycle, model=MODEL, term=product_id, property=TERM_ID
+    ) if kg_carcass_weight else None
 
     return kg_liveweight, groupingFAO
 
@@ -77,7 +81,7 @@ def _run_liveAnimal(cycle: dict, product: dict, year: int, country_id: str):
     animal_product_id = get_liveAnimal_to_animalProduct_id(product_id, LOOKUPS['liveAnimal'][0], term=TERM_ID)
 
     animal_product_term = download_term(animal_product_id, TermTermType.ANIMALPRODUCT) if animal_product_id else {}
-    kg_liveweight, groupingFAO = _product_value({**product, 'term': animal_product_term}, year, country_id)
+    kg_liveweight, groupingFAO = _product_value(cycle, {**product, 'term': animal_product_term}, year, country_id)
 
     logRequirements(cycle, model=MODEL, term=product_id, property=TERM_ID,
                     animal_product_id=animal_product_id,
@@ -94,7 +98,7 @@ def _run_liveAnimal(cycle: dict, product: dict, year: int, country_id: str):
 
 def _run_animalProduct(cycle: dict, product: dict, year: int, country_id: str):
     product_id = product.get('term', {}).get('@id')
-    kg_liveweight, groupingFAO = _product_value(product, year, country_id)
+    kg_liveweight, groupingFAO = _product_value(cycle, product, year, country_id)
 
     logRequirements(cycle, model=MODEL, term=product_id, property=TERM_ID,
                     country_id=country_id,
