@@ -1,19 +1,20 @@
-from numpy import recarray
 from hestia_earth.schema import TermTermType
 from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name, extract_grouped_data_closest_date
-from hestia_earth.utils.tools import safe_parse_float, flatten
+from hestia_earth.utils.tools import safe_parse_float, flatten, non_empty_list
 
-from hestia_earth.models.log import logger, debugMissingLookup, logRequirements, logShouldRun, debugValues
+from hestia_earth.models.log import logger, debugMissingLookup, logRequirements, logShouldRun, debugValues, log_as_table
 from hestia_earth.models.utils.animalProduct import (
     FAO_LOOKUP_COLUMN, FAO_EQUIVALENT_LOOKUP_COLUMN, get_animalProduct_lookup_value
 )
 from hestia_earth.models.utils.product import convert_product_to_unit
 from hestia_earth.models.utils.impact_assessment import get_country_id, impact_end_year
 from hestia_earth.models.utils.indicator import _new_indicator
+from hestia_earth.models.utils.lookup import get_region_lookup_value
 from . import MODEL
 
 LOOKUP_PREFIX = f"{TermTermType.REGION.value}-{TermTermType.ANIMALPRODUCT.value}-{FAO_LOOKUP_COLUMN}"
+FAOSTAT_AREA_LOOKUP = 'region-faostatArea.csv'
 
 
 def get_liveAnimal_to_animalProduct_id(product_term_id: str, column: str, **log_args):
@@ -32,13 +33,11 @@ def product_equivalent_value(product: dict, year: int, country: str):
     if not grouping or not fao_product_id:
         return None
 
-    lookup = download_lookup(f"{LOOKUP_PREFIX}-productionQuantity.csv")
-    quantity_values = get_table_value(lookup, 'termid', country, column_name(grouping))
-    quantity = safe_parse_float(extract_grouped_data_closest_date(quantity_values, year))
+    quantity_values = get_region_lookup_value(f"{LOOKUP_PREFIX}-productionQuantity.csv", country, grouping)
+    quantity = safe_parse_float(extract_grouped_data_closest_date(quantity_values, year), default=0)
 
-    lookup = download_lookup(f"{LOOKUP_PREFIX}-head.csv")
-    head_values = get_table_value(lookup, 'termid', country, column_name(grouping))
-    head = safe_parse_float(extract_grouped_data_closest_date(head_values, year))
+    head_values = get_region_lookup_value(f"{LOOKUP_PREFIX}-head.csv", country, grouping)
+    head = safe_parse_float(extract_grouped_data_closest_date(head_values, year), default=0)
 
     # quantity is in Tonnes
     value = quantity * 1000 / head if head > 0 else 0
@@ -59,26 +58,26 @@ def product_equivalent_value(product: dict, year: int, country: str):
 def _split_delta(table_value: str, start_year: int, end_year: int):
     start_value = extract_grouped_data_closest_date(table_value, start_year)
     end_value = extract_grouped_data_closest_date(table_value, end_year)
-    return safe_parse_float(end_value) - safe_parse_float(start_value) if all([
+    return safe_parse_float(end_value, default=None) - safe_parse_float(start_value, default=None) if all([
         start_value is not None, end_value is not None
     ]) else None
 
 
-def get_sum_of_columns(lookup: recarray, country: str, year: int, columns_list: list) -> float:
+def get_sum_of_columns(country: str, year: int, columns_list: list) -> float:
     return sum(
         [safe_parse_float(
             extract_grouped_data_closest_date(
-                data=get_table_value(lookup, 'termid', country, column_name(col)),
+                data=get_region_lookup_value(FAOSTAT_AREA_LOOKUP, country, col, model=MODEL),
                 year=year
-            )
+            ),
+            default=0
         ) for col in columns_list]
     )
 
 
 def get_single_delta(country: str, start_year: int, end_year: int, column: str):
-    lookup = download_lookup('region-faostatArea.csv')
     return _split_delta(
-        get_table_value(lookup, 'termid', country, column_name(column)), start_year, end_year
+        get_region_lookup_value(FAOSTAT_AREA_LOOKUP, country, column, model=MODEL), start_year, end_year
     )
 
 
@@ -88,27 +87,24 @@ def get_land_ratio(
     """
     total_column is optional. Assumes that, if missing, total is the sum of values from first and second.
     """
-    lookup = download_lookup('region-faostatArea.csv')
     first_delta = _split_delta(
-        get_table_value(lookup, 'termid', country, column_name(first_column)), start_year, end_year
+        get_region_lookup_value(FAOSTAT_AREA_LOOKUP, country, first_column, model=MODEL), start_year, end_year
     )
     second_delta = _split_delta(
-        get_table_value(lookup, 'termid', country, column_name(second_column)), start_year, end_year
+        get_region_lookup_value(FAOSTAT_AREA_LOOKUP, country, second_column, model=MODEL), start_year, end_year
     )
     total_delta = (
         get_sum_of_columns(
-            lookup=lookup,
             country=country,
             year=end_year,
             columns_list=[first_column, second_column]
         ) - get_sum_of_columns(
-            lookup=lookup,
             country=country,
             year=start_year,
             columns_list=[first_column, second_column]
         )
     ) if total_column is None else _split_delta(
-        get_table_value(lookup, 'termid', country, column_name(total_column)), start_year, end_year
+        get_region_lookup_value(FAOSTAT_AREA_LOOKUP, country, total_column, model=MODEL), start_year, end_year
     )
 
     return (None, None, None) if any([
@@ -130,18 +126,11 @@ def get_cropland_ratio(country: str, start_year: int, end_year: int):
 
 
 def get_change_in_harvested_area_for_crop(country_id: str, crop_name: str, start_year: int, end_year: int = 0):
-    lookup = download_lookup('region-crop-cropGroupingFaostatProduction-areaHarvested.csv')
-    if end_year == 0 or end_year == start_year:
-        return safe_parse_float(
-            extract_grouped_data_closest_date(
-                data=get_table_value(lookup, 'termid', country_id, column_name(crop_name)),
-                year=start_year
-            )
-        )
-    else:
-        return _split_delta(
-            get_table_value(lookup, 'termid', country_id, column_name(crop_name)), start_year, end_year
-        )
+    lookup_name = 'region-crop-cropGroupingFaostatProduction-areaHarvested.csv'
+    value = get_region_lookup_value(lookup_name, country_id, crop_name)
+    return safe_parse_float(
+        extract_grouped_data_closest_date(value, start_year), default=0
+    ) if end_year == 0 or end_year == start_year else _split_delta(value, start_year, end_year)
 
 
 def should_run_landTransformationFromCropland(term_id: str, impact: dict):
@@ -163,24 +152,45 @@ def should_run_landTransformationFromCropland(term_id: str, impact: dict):
     return should_run, indicators
 
 
+def _map_indicator_value(impact: dict, start_year: int, end_year: int):
+    def mapper(indicator: dict):
+        country_id = get_country_id(impact, blank_node=indicator)
+        total, permanent, temporary = get_cropland_ratio(country_id, start_year, end_year)
+        return {
+            'landCover-id': indicator.get('landCover', {}).get('@id'),
+            'value': indicator.get('value'),
+            'country-id': country_id,
+            'diff-total-area': total,
+            'diff-temporary-area': temporary,
+            'diff-permanent-area': permanent
+        } if total is not None else None
+    return mapper
+
+
 def run_landTransformationFromCropland(term_id: str, impact: dict, indicators: list, years: int):
-    country_id = get_country_id(impact)
     end_year = impact_end_year(impact)
-    total, permanent, temporary = get_cropland_ratio(country_id, end_year - years, end_year)
+
+    values = non_empty_list(map(_map_indicator_value(impact, end_year - years, end_year), indicators))
 
     debugValues(impact, model=MODEL, term_id=term_id,
-                diff_temporary_area=temporary,
-                diff_permanent_area=permanent,
-                diff_total_area=total)
+                indicators_used=log_as_table(values))
 
     return flatten([
         [
-            _new_indicator(term_id, MODEL, indicator.get('landCover', {}).get('@id'), 'annualCropland') | {
-                'value': indicator.get('value') * temporary / total
-            },
-            _new_indicator(term_id, MODEL, indicator.get('landCover', {}).get('@id'), 'permanentCropland') | {
-                'value': indicator.get('value') * permanent / total
-            }
+            _new_indicator(
+                term=term_id,
+                value=value.get('value') * value.get('diff-temporary-area') / value.get('diff-total-area'),
+                model=MODEL,
+                land_cover_id=value.get('landCover-id'),
+                previous_land_cover_id='annualCropland'
+            ),
+            _new_indicator(
+                term=term_id,
+                value=value.get('value') * value.get('diff-permanent-area') / value.get('diff-total-area'),
+                model=MODEL,
+                land_cover_id=value.get('landCover-id'),
+                previous_land_cover_id='permanentCropland'
+            )
         ]
-        for indicator in indicators
-    ]) if total is not None else []
+        for value in values
+    ])
