@@ -34,8 +34,7 @@ BIBLIO_TITLE = 'An Enhanced Global Elevation Model Generalized From Multiple Hig
 
 
 def _measurement(site: dict, value: float):
-    measurement = _new_measurement(TERM_ID)
-    measurement['value'] = [value]
+    measurement = _new_measurement(term=TERM_ID, value=value)
     measurement['methodClassification'] = MeasurementMethodClassification.GEOSPATIAL_DATASET.value
     return measurement | get_source(site, BIBLIO_TITLE)
 
