@@ -37,8 +37,7 @@ BIBLIO_TITLE = 'ERA5: Fifth generation of ECMWF atmospheric reanalyses of the gl
 
 
 def _measurement(site: dict, value: list, dates: list):
-    measurement = _new_measurement(TERM_ID)
-    measurement['value'] = value
+    measurement = _new_measurement(term=TERM_ID, value=value)
     measurement['dates'] = dates
     measurement['methodClassification'] = MeasurementMethodClassification.GEOSPATIAL_DATASET.value
     return measurement | get_source(site, BIBLIO_TITLE)
