@@ -34,8 +34,7 @@ BIBLIO_TITLE = 'Modelling spatially explicit impacts from phosphorus emissions i
 
 
 def _measurement(site: dict, value: float):
-    measurement = _new_measurement(TERM_ID)
-    measurement['value'] = [value]
+    measurement = _new_measurement(term=TERM_ID, value=value)
     measurement['depthUpper'] = 0
     measurement['depthLower'] = 50
     measurement['methodClassification'] = MeasurementMethodClassification.GEOSPATIAL_DATASET.value
