@@ -22,8 +22,7 @@ TERM_ID = 'freshWater'
 
 
 def _measurement():
-    data = _new_measurement(TERM_ID, MODEL)
-    data['value'] = [True]
+    data = _new_measurement(term=TERM_ID, model=MODEL, value=True)
     data['methodClassification'] = MeasurementMethodClassification.MODELLED_USING_OTHER_MEASUREMENTS.value
     return data
 
