@@ -1,9 +1,9 @@
 from hestia_earth.schema import SiteSiteType, TermTermType
 from hestia_earth.utils.model import linked_node
+from hestia_earth.utils.term import download_term
 
 from hestia_earth.models.log import logRequirements, logShouldRun
 from hestia_earth.models.utils.practice import _new_practice
-from hestia_earth.models.utils.term import download_term
 from . import MODEL
 
 REQUIREMENTS = {
@@ -25,10 +25,9 @@ KEY_TERM_ID = 'genericGrassPlant'
 
 
 def _practice():
-    node = _new_practice(TERM_ID, MODEL)
-    node['value'] = [100]
-    node['key'] = linked_node(download_term(KEY_TERM_ID, TermTermType.LANDCOVER))
-    return node
+    practice = _new_practice(term=TERM_ID, model=MODEL, value=100)
+    practice['key'] = linked_node(download_term(KEY_TERM_ID, TermTermType.LANDCOVER))
+    return practice
 
 
 def _should_run(cycle: dict):
