@@ -4,15 +4,15 @@ from hestia_earth.utils.lookup import (
     download_lookup, column_name, extract_grouped_data_closest_date, find_term_ids_by
 )
 from hestia_earth.utils.model import filter_list_term_type
-from hestia_earth.utils.tools import non_empty_list, flatten, list_sum, safe_parse_float
+from hestia_earth.utils.tools import non_empty_list, flatten, list_sum, safe_parse_float, omit
 from hestia_earth.utils.emission import cycle_emissions_in_system_boundary
 
 from hestia_earth.models.log import logRequirements, logShouldRun, log_as_table, debugValues
-from hestia_earth.models.utils import _omit, group_by
+from hestia_earth.models.utils import group_by
 from hestia_earth.models.utils.emission import _new_emission
 from hestia_earth.models.utils.site import valid_site_type
 from hestia_earth.models.utils.cycle import cycle_end_year
-from hestia_earth.models.utils.crop import get_crop_grouping_faostat_production, get_landCover_term_id
+from hestia_earth.models.utils.crop import get_crop_lookup_value, get_landCover_term_id
 from hestia_earth.models.utils.completeness import _is_term_type_complete
 from hestia_earth.models.utils.term import get_lookup_value
 from hestia_earth.models.utils.lookup import get_region_lookup_value
@@ -59,6 +59,7 @@ LOOKUPS = {
     "crop": [
         "correspondingSeedTermIds",
         "cropGroupingFaostatProduction",
+        "cropGroupingFaostatProductionProxy",
         "global_economic_value_share",
         "landCoverTermId"
     ],
@@ -69,8 +70,7 @@ TIER = EmissionMethodTier.BACKGROUND.value
 
 
 def _emission(term_id: str, value: float, input: dict):
-    emission = _new_emission(term_id, MODEL)
-    emission['value'] = [round(value, 7)]
+    emission = _new_emission(term=term_id, model=MODEL, value=value)
     emission['inputs'] = [input]
     emission['methodTier'] = TIER
     return emission
@@ -109,10 +109,11 @@ def _map_group_emissions(group_id: str, required_emission_term_ids: list, emissi
     missing_emissions = list(filter(lambda v: v not in emission_ids, emissions))
     return {
         'group-id': group_id,
+        'is-group-in-system-boundary': group_id in required_emission_term_ids,
         'total-emissions': len(emissions),
         'included-emissions': len(included_emissions),
         'missing-emissions': '-'.join(missing_emissions),
-        'is-valid': len(emissions) == len(included_emissions)
+        'has-all-emissions': len(emissions) == len(included_emissions)
     }
 
 
@@ -140,7 +141,10 @@ def _filter_emissions(cycle: dict):
         for group_id in group_ids
     ]
     # only keep groups that have all emissions present in the Cycle
-    valid_groups = list(filter(lambda group: group.get('is-valid'), emissions_per_group))
+    valid_groups = list(filter(lambda group: all([
+        group.get('has-all-emissions'),
+        group.get('is-group-in-system-boundary')
+    ]), emissions_per_group))
     valid_group_ids = set([v.get('group-id') for v in valid_groups])
 
     # finally, only return emissions which groups are valid
@@ -150,23 +154,38 @@ def _filter_emissions(cycle: dict):
     )), emissions_per_group
 
 
-def _evs(product: dict):
-    return safe_parse_float(
-        get_lookup_value(product.get('term', {}), 'global_economic_value_share', model=MODEL, model_key=MODEL_KEY),
-        default=None
-    ) or product.get('economicValueShare')
+def _crop_data(product: dict, country_id: str, end_year: int):
+    term = product.get('term', {})
+    term_id = term.get('@id')
 
+    crop_grouping = get_crop_lookup_value(MODEL, term_id, term_id, 'cropGroupingFaostatProduction')
+    crop_grouping_proxy = get_crop_lookup_value(MODEL, term_id, term_id, 'cropGroupingFaostatProductionProxy')
 
-def _faostat_yield(country_id: str, end_year: int, product: dict):
-    grouping = get_crop_grouping_faostat_production(MODEL, product.get('term', {}))
-    value = extract_grouped_data_closest_date(get_region_lookup_value(
+    faostat_yield = safe_parse_float(extract_grouped_data_closest_date(get_region_lookup_value(
         'region-crop-cropGroupingFaostatProduction-yield.csv',
         country_id,
-        grouping,
+        crop_grouping_proxy or crop_grouping,
         model=MODEL,
         model_key=MODEL_KEY
-    ), end_year)
-    return safe_parse_float(value, default=None)
+    ), end_year), default=None)
+
+    # when using proxy, we cannot use the lookup value as it won't correspond to the primary product
+    global_evs = None if crop_grouping_proxy else safe_parse_float(
+        get_lookup_value(product.get('term', {}), 'global_economic_value_share', model=MODEL, model_key=MODEL_KEY),
+        default=None
+    )
+    product_evs = product.get('economicValueShare')
+
+    return {
+        'product-id': term_id,
+        'seed-id': get_lookup_value(term, 'correspondingSeedTermIds', model=MODEL, model_key=MODEL_KEY) or None,
+        'economicValueShare': global_evs or product_evs,
+        'FAOSTAT-yield': faostat_yield,
+        'landCover-id': get_landCover_term_id(term, model=MODEL, model_key=MODEL_KEY)
+    } | (
+        # skip using product yield if proxy is used
+        {} if crop_grouping_proxy else {'product-yield': list_sum(product.get('value'))}
+    )
 
 
 def _group_seed_inputs(inputs: list):
@@ -187,18 +206,7 @@ def _should_run(cycle: dict):
     country_id = cycle.get('site', {}).get('country', {}).get('@id')
 
     # only keep the crop products that map to a seed
-    crop_products = [
-        {
-            'product': product.get('term', {}).get('@id'),
-            'seed-id': get_lookup_value(
-                product.get('term', {}), 'correspondingSeedTermIds', model=MODEL, model_key=MODEL_KEY) or None,
-            'economicValueShare': _evs(product),
-            'FAOSTAT-yield': _faostat_yield(country_id, end_year, product),
-            'product-yield': list_sum(product.get('value')),
-            'landCover-id': get_landCover_term_id(product.get('term', {}), model=MODEL, model_key=MODEL_KEY)
-        }
-        for product in crop_products
-    ]
+    crop_products = [_crop_data(product, country_id, end_year) for product in crop_products]
     valid_crop_products = [
         value for value in crop_products if all([
             value.get('seed-id'),
@@ -275,7 +283,7 @@ def _should_run(cycle: dict):
         logRequirements(cycle, model=MODEL, term=term_id, model_key=MODEL_KEY,
                         emissions=log_as_table(emissions),
                         emissions_per_group=log_as_table(emissions_per_group),
-                        **_omit(seed_input, 'input'),
+                        **omit(seed_input, 'input'),
                         **logs)
 
         logShouldRun(cycle, MODEL, term_id, should_run, methodTier=TIER, model_key=MODEL_KEY)
@@ -283,10 +291,10 @@ def _should_run(cycle: dict):
         # log failed emissions to show in the logs
         for group in emissions_per_group:
             emission_id = group.get('group-id')
-            if not group.get('is-valid') or not should_run:
+            if not group.get('has-all-emissions') or not should_run:
                 logRequirements(cycle, model=MODEL, term=term_id, model_key=MODEL_KEY, emission_id=emission_id,
                                 **group,
-                                **_omit(seed_input, 'input'),
+                                **omit(seed_input, 'input'),
                                 **logs)
                 logShouldRun(cycle, MODEL, term_id, False,
                              methodTier=TIER, model_key=MODEL_KEY, emission_id=emission_id)
