@@ -35,18 +35,14 @@ RETURNS = {
 MODEL_KEY = 'milkYieldPerAnimal'
 
 
-def _practice(term_id: str, value: float):
-    node = _new_practice(term_id, MODEL)
-    node['value'] = [value]
-    return node
-
-
 def _run_animal(data: dict):
     animal = data.get('animal')
     value = data.get('value')
     practice_id = get_lookup_value(animal.get('term'), LOOKUPS['liveAnimal'][1])
     return animal | ({
-        'practices': merge_blank_nodes(animal.get('practices', []), [_practice(practice_id, value)])
+        'practices': merge_blank_nodes(animal.get('practices', []), [
+            _new_practice(term=practice_id, model=MODEL, value=value)
+        ])
     } if practice_id else {})
 
 
