@@ -549,7 +549,7 @@ def _measurement(
         "dates": [f"{year}-12-31" for year in timestamps],
         "methodClassification": _METHOD_CLASSIFICATION
     }
-    measurement = _new_measurement(TERM_ID, MODEL) | {
+    measurement = _new_measurement(term=TERM_ID, model=MODEL) | {
         key: value for key, value in update_dict.items() if value
     }
     measurement["depthUpper"] = _DEPTH_UPPER
