@@ -36,9 +36,7 @@ TERM_ID = 'belowGroundCropResidue'
 PROPERTY_KEY = 'dryMatter'
 
 
-def _product(value: float):
-    product = _new_product(TERM_ID, value, MODEL)
-    return product
+def _product(value: float = None): return _new_product(term=TERM_ID, model=MODEL, value=value)
 
 
 def _get_lookup_value(term: dict, column: str):
