@@ -1,4 +1,4 @@
-from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition, TermTermType, SiteSiteType
+from hestia_earth.schema import EmissionMethodTier, TermTermType, SiteSiteType
 
 from hestia_earth.models.log import logRequirements, logShouldRun
 from hestia_earth.models.utils.constant import Units, get_atomic_conversion
@@ -57,14 +57,8 @@ TIER = EmissionMethodTier.TIER_1.value
 
 
 def _emission(value: float, sd: float = None, min: float = None, max: float = None):
-    emission = _new_emission(TERM_ID, MODEL)
-    emission['value'] = [value]
-    if sd is not None:
-        emission['sd'] = [sd]
-        emission['min'] = [min]
-        emission['max'] = [max]
+    emission = _new_emission(term=TERM_ID, model=MODEL, value=value, min=min, max=max, sd=sd)
     emission['methodTier'] = TIER
-    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
@@ -98,7 +92,7 @@ def _should_run(cycle: dict):
 
     use_excreta_management = _should_run_with_excreta_management(cycle)
     excreta_EF_input = get_excreta_inputs_with_factor(
-        cycle, f"{list(LOOKUPS.keys())[0]}.csv", excreta_convertion_func=total_excreta, model=MODEL, term=TERM_ID
+        cycle, f"{list(LOOKUPS.keys())[0]}.csv", excreta_conversion_func=total_excreta, model=MODEL, term=TERM_ID
     ) if use_excreta_management else None
 
     logRequirements(cycle, model=MODEL, term=TERM_ID,
