@@ -380,7 +380,7 @@ def _emission(term_id: str, **kwargs) -> dict:
     """
     Build a HESTIA [Emission node](https://www.hestia.earth/schema/Emission) using model output data.
     """
-    emission = _new_emission(term_id, MODEL)
+    emission = _new_emission(term=term_id, model=MODEL)
     return emission | {
         **{k: v for k, v in kwargs.items()},
         "methodTier": TIER
