@@ -3,35 +3,112 @@ from functools import reduce
 from numpy import empty_like, random, vstack
 from numpy.typing import NDArray
 from pydash.objects import merge
-from typing import Callable, Optional, Union
-
+from typing import Callable, Literal, Optional, Union
 from hestia_earth.schema import MeasurementMethodClassification, SiteSiteType, TermTermType
-from hestia_earth.utils.model import find_term_match, filter_list_term_type
 from hestia_earth.utils.blank_node import get_node_value
+from hestia_earth.utils.model import find_term_match, filter_list_term_type
+from hestia_earth.utils.tools import non_empty_list
+from hestia_earth.utils.stats import gen_seed
+from hestia_earth.utils.descriptive_stats import calc_descriptive_stats
 
 from hestia_earth.models.utils import split_on_condition
-from hestia_earth.models.utils.array_builders import gen_seed
 from hestia_earth.models.utils.blank_node import (
-    cumulative_nodes_match, cumulative_nodes_lookup_match, cumulative_nodes_term_match, node_lookup_match,
-    node_term_match, group_nodes_by_year, validate_start_date_end_date
+    cumulative_nodes_match, cumulative_nodes_lookup_match, cumulative_nodes_term_match, group_by_term,
+    node_lookup_match, node_term_match, group_nodes_by_year, validate_start_date_end_date
 )
 from hestia_earth.models.utils.ecoClimateZone import EcoClimateZone, get_eco_climate_zone_value
-from hestia_earth.models.utils.descriptive_stats import calc_descriptive_stats
 from hestia_earth.models.utils.measurement import _new_measurement
 from hestia_earth.models.utils.property import get_node_property
-from hestia_earth.models.utils.term import get_residue_removed_or_burnt_terms, get_upland_rice_land_cover_terms
+from hestia_earth.models.utils.term import (
+    get_lookup_value, get_residue_removed_or_burnt_terms, get_upland_rice_land_cover_terms
+)
 
 from .organicCarbonPerHa_utils import (
-    check_irrigation, DEPTH_LOWER, DEPTH_UPPER, IPCC_SOIL_CATEGORY_TO_SOIL_TYPE_LOOKUP_VALUE,
+    check_irrigation, DEPTH_LOWER, DEPTH_UPPER, format_soil_inventory, IPCC_SOIL_CATEGORY_TO_SOIL_TYPE_LOOKUP_VALUE,
     IPCC_LAND_USE_CATEGORY_TO_LAND_COVER_LOOKUP_VALUE, IPCC_MANAGEMENT_CATEGORY_TO_GRASSLAND_MANAGEMENT_TERM_ID,
     IPCC_MANAGEMENT_CATEGORY_TO_TILLAGE_MANAGEMENT_LOOKUP_VALUE, IpccSoilCategory, IpccCarbonInputCategory,
     IpccLandUseCategory, IpccManagementCategory, is_cover_crop, MIN_AREA_THRESHOLD, sample_constant,
-    sample_plus_minus_error, sample_plus_minus_uncertainty, SITE_TYPE_TO_IPCC_LAND_USE_CATEGORY,
+    sample_plus_minus_error, sample_plus_minus_uncertainty, SITE_TYPE_TO_IPCC_LAND_USE_CATEGORY, SoilData,
     SUPER_MAJORITY_AREA_THRESHOLD, STATS_DEFINITION
 )
 from . import MODEL
 
-_LOOKUPS = {
+REQUIREMENTS = {
+    "Site": {
+        "management": [
+            {"@type": "Management", "value": "", "term.termType": "landCover"}
+        ],
+        "measurements": [
+            {
+                "@type": "Measurement",
+                "value": ["1", "2", "3", "4", "7", "8", "9", "10", "11", "12"],
+                "term.@id": "ecoClimateZone"
+            }
+        ],
+        "optional": {
+            "measurements": [
+                {
+                    "@doc": "This model cannot run on sites with more than 30 percent organic soils (`histols`, `histosol` and their subclasses).",  # noqa: E501
+                    "@type": "Measurement", "value": "",
+                    "term.termType": ["soilType", "usdaSoilType"]
+                }
+            ],
+            "management": [
+                {
+                    "@type": "Management",
+                    "value": "",
+                    "startDate": "",
+                    "endDate": "",
+                    "term.termType": "cropResidueManagement",
+                    "name": ["burnt", "removed"]
+                },
+                {
+                    "@type": "Management",
+                    "value": "",
+                    "startDate": "",
+                    "endDate": "",
+                    "term.termType": "landUseManagement"
+                },
+                {"@type": "Management", "value": "", "startDate": "", "endDate": "", "term.termType": "tillage"},
+                {
+                    "@type": "Management",
+                    "value": "",
+                    "startDate": "",
+                    "endDate": "",
+                    "term.termType": "waterRegime",
+                    "name": ["deep water", "irrigated"]
+                },
+                {
+                    "@type": "Management",
+                    "value": "",
+                    "startDate": "",
+                    "endDate": "",
+                    "term.@id": "amendmentIncreasingSoilCarbonUsed"
+                },
+                {"@type": "Management", "value": "", "startDate": "", "endDate": "", "term.@id": "animalManureUsed"},
+                {
+                    "@type": "Management",
+                    "value": "",
+                    "startDate": "",
+                    "endDate": "",
+                    "term.@id": "inorganicNitrogenFertiliserUsed"
+                },
+                {
+                    "@type": "Management",
+                    "value": "",
+                    "startDate": "",
+                    "endDate": "",
+                    "term.@id": "organicFertiliserUsed"
+                },
+                {"@type": "Management", "value": "", "startDate": "", "endDate": "", "term.@id": "shortBareFallow"}
+            ]
+        },
+        "none": {
+            "siteType": ["glass or high accessible cover"]
+        }
+    }
+}
+LOOKUPS = {
     "crop": "IPCC_LAND_USE_CATEGORY",
     "landCover": [
         "IPCC_LAND_USE_CATEGORY",
@@ -43,6 +120,20 @@ _LOOKUPS = {
     "tillage": "IPCC_TILLAGE_MANAGEMENT_CATEGORY",
     "usdaSoilType": "IPCC_SOIL_CATEGORY"
 }
+RETURNS = {
+    "Measurement": [{
+        "value": "",
+        "sd": "",
+        "min": "",
+        "max": "",
+        "statsDefinition": "simulated",
+        "observations": "",
+        "dates": "",
+        "depthUpper": "0",
+        "depthLower": "30",
+        "methodClassification": "tier 1 model"
+    }]
+}
 
 TERM_ID = 'organicCarbonPerHa'
 _METHOD_CLASSIFICATION = MeasurementMethodClassification.TIER_1_MODEL.value
@@ -108,7 +199,7 @@ def _measurement(
     dict
         A valid HESTIA `Measurement` node, see: https://www.hestia.earth/schema/Measurement.
     """
-    measurement = _new_measurement(TERM_ID) | descriptive_stats_dict
+    measurement = _new_measurement(term=TERM_ID, model=MODEL) | descriptive_stats_dict
     measurement["dates"] = [f"{year}-12-31" for year in timestamps]
     measurement["depthUpper"] = DEPTH_UPPER
     measurement["depthLower"] = DEPTH_LOWER
@@ -521,16 +612,19 @@ def should_run(site: dict) -> tuple[bool, dict, dict]:
     measurement_nodes = site.get("measurements", [])
 
     eco_climate_zone = get_eco_climate_zone_value(site, as_enum=True)
-    ipcc_soil_category = _assign_ipcc_soil_category(measurement_nodes)
+    ipcc_soil_category, soil_logs = _assign_ipcc_soil_category(measurement_nodes)
     soc_ref = _get_soc_ref_preview(ipcc_soil_category, eco_climate_zone)
 
+    valid_site_type = site_type in _VALID_SITE_TYPES
+    valid_eco_climate_zone = eco_climate_zone not in _EXCLUDED_ECO_CLIMATE_ZONES
+    valid_soc_ref = isinstance(soc_ref, (float, int)) and soc_ref > 0
     has_management = len(management_nodes) > 0
     has_measurements = len(measurement_nodes) > 0
 
     should_compile_inventory = all([
-        site_type in _VALID_SITE_TYPES,
-        eco_climate_zone not in _EXCLUDED_ECO_CLIMATE_ZONES,
-        soc_ref or -9999 > 0,
+        valid_site_type,
+        valid_eco_climate_zone,
+        valid_soc_ref,
         has_management,
         has_measurements
     ])
@@ -553,9 +647,13 @@ def should_run(site: dict) -> tuple[bool, dict, dict]:
         year for year, group in inventory.items() if group.get(_InventoryKey.SHOULD_RUN)
     )
 
-    logs = inventory_logs | {
+    logs = soil_logs | inventory_logs | {
         "site_type": site_type,
+        "soc_ref_available": valid_soc_ref,
         "soc_ref": soc_ref,
+        "valid_eco_climate_zone": valid_eco_climate_zone,
+        "valid_soil_category": ipcc_soil_category not in [IpccSoilCategory.ORGANIC_SOILS],
+        "valid_site_type": valid_site_type,
         "has_management": has_management,
         "has_measurements": has_measurements,
         "should_compile_inventory_tier_1": should_compile_inventory,
@@ -946,34 +1044,74 @@ def _assign_ipcc_soil_category(
     IpccSoilCategory
         The assigned IPCC soil category.
     """
-    soil_types = filter_list_term_type(measurement_nodes, TermTermType.SOILTYPE)
-    usda_soil_types = filter_list_term_type(measurement_nodes, TermTermType.USDASOILTYPE)
+    soil_types = _get_soil_type_measurements(measurement_nodes, TermTermType.SOILTYPE)
+    usda_soil_types = _get_soil_type_measurements(measurement_nodes, TermTermType.USDASOILTYPE)
+
+    soil_data = [_unpack_soil_data(node) for node in soil_types]
+    usda_soil_data = [_unpack_soil_data(node) for node in usda_soil_types]
 
     clay_content = get_node_value(find_term_match(measurement_nodes, _CLAY_CONTENT_TERM_ID))
     sand_content = get_node_value(find_term_match(measurement_nodes, _SAND_CONTENT_TERM_ID))
-
     has_sandy_soil = clay_content < _CLAY_CONTENT_MAX and sand_content > _SAND_CONTENT_MIN
 
-    return next(
+    logs = {
+        "soil_data": format_soil_inventory(soil_data),
+        "usda_soil_data": format_soil_inventory(usda_soil_data),
+        "has_sandy_soil_texture": has_sandy_soil
+    }
+
+    category = next(
         (
             key for key in _SOIL_CATEGORY_DECISION_TREE
-            if _SOIL_CATEGORY_DECISION_TREE[key](
+            if _check_soil_category(
                 key=key,
-                soil_types=soil_types,
-                usda_soil_types=usda_soil_types,
+                soil_data=soil_data,
+                usda_soil_data=usda_soil_data,
                 has_sandy_soil=has_sandy_soil
             )
         ),
         default
     ) if len(soil_types) > 0 or len(usda_soil_types) > 0 else default
 
+    return category, logs
+
+
+def _get_soil_type_measurements(
+    nodes: list[dict], term_type: Literal[TermTermType.SOILTYPE, TermTermType.USDASOILTYPE]
+) -> list[dict]:
+    grouped = group_by_term(filter_list_term_type(nodes, term_type))
+
+    def depth_distance(node):
+        upper, lower = node.get("depthUpper", 0), node.get("depthLower", 100)
+        return abs(upper - DEPTH_UPPER) + abs(lower - DEPTH_LOWER)
+
+    return non_empty_list(
+        min(nodes_, key=depth_distance) for key in grouped if (nodes_ := grouped.get(key, []))
+    )
+
+
+def _unpack_soil_data(node):
+    term = node.get("term", {})
+    term_id = term.get("@id")
+    term_type = term.get("termType")
+    value = get_node_value(node)
+
+    lookup_value = get_lookup_value(term, LOOKUPS[term_type]) if term_type else None
+    category = next(key for key, value in IPCC_SOIL_CATEGORY_TO_SOIL_TYPE_LOOKUP_VALUE.items() if value == lookup_value)
+
+    return SoilData(term_id, value, category)
+
+
+_IPCC_SOIL_CATEGORY_TO_OVERRIDE_KWARGS = {
+    IpccSoilCategory.SANDY_SOILS: {"has_sandy_soil"}
+}
+"""
+Keyword arguments that can override the `soilType`/`usdaSoilType` lookup match for an `IpccSoilCategory`.
+"""
+
 
 def _check_soil_category(
-    *,
-    key: IpccSoilCategory,
-    soil_types: list[dict],
-    usda_soil_types: list[dict],
-    **_
+    *, key: IpccSoilCategory, soil_data: list[SoilData], usda_soil_data: list[SoilData], **kwargs
 ) -> bool:
     """
     Check if the soil category matches the given key.
@@ -982,84 +1120,36 @@ def _check_soil_category(
     ----------
     key : IpccSoilCategory
         The IPCC soil category to check.
-    soil_types : list[dict]
-        List of soil type measurement nodes.
-    usda_soil_types : list[dict]
-        List of USDA soil type measurement nodes
+    soil_data : list[SoilData]
+        List of `SoilData` NamedEnums generated from `soilType` measurement nodes.
+    usda_soil_data : list[SoilData]
+        List of `SoilData` NamedEnums generated from `usdaSoilType` measurement nodes.
 
     Returns
     -------
     bool
         `True` if the soil category matches, `False` otherwise.
     """
-    SOIL_TYPE_LOOKUP = _LOOKUPS["soilType"]
-    USDA_SOIL_TYPE_LOOKUP = _LOOKUPS["usdaSoilType"]
+    override_kwargs = _IPCC_SOIL_CATEGORY_TO_OVERRIDE_KWARGS.get(key, set())
+    valid_override = any(v for k, v in kwargs.items() if k in override_kwargs)
 
-    target_lookup_values = IPCC_SOIL_CATEGORY_TO_SOIL_TYPE_LOOKUP_VALUE.get(key, None)
+    is_soil_match = sum(data.value for data in soil_data if data.category == key) > MIN_AREA_THRESHOLD
+    is_usda_soil_match = sum(data.value for data in usda_soil_data if data.category == key) > MIN_AREA_THRESHOLD
 
-    is_soil_type_match = cumulative_nodes_lookup_match(
-        soil_types,
-        lookup=SOIL_TYPE_LOOKUP,
-        target_lookup_values=target_lookup_values,
-        cumulative_threshold=MIN_AREA_THRESHOLD
-    )
-
-    is_usda_soil_type_match = cumulative_nodes_lookup_match(
-        usda_soil_types,
-        lookup=USDA_SOIL_TYPE_LOOKUP,
-        target_lookup_values=target_lookup_values,
-        cumulative_threshold=MIN_AREA_THRESHOLD
-    )
-
-    return is_soil_type_match or is_usda_soil_type_match
+    return valid_override or is_soil_match or is_usda_soil_match
 
 
-def _check_sandy_soil_category(
-    *,
-    key: IpccSoilCategory,
-    soil_types: list[dict],
-    usda_soil_types: list[dict],
-    has_sandy_soil: bool,
-    **_
-) -> bool:
-    """
-    Check if the soils are sandy.
-
-    This function is special case of `_check_soil_category`.
-
-    Parameters
-    ----------
-    key : IpccSoilCategory
-        The IPCC soil category to check.
-    soil_types : list[dict]
-        List of soil type measurement nodes.
-    usda_soil_types : list[dict]
-        List of USDA soil type measurement nodes
-    has_sandy_soil : bool
-        True if the soils are sandy, False otherwise.
-
-    Returns
-    -------
-    bool
-        `True` if the soil category matches, `False` otherwise.
-    """
-    return _check_soil_category(key=key, soil_types=soil_types, usda_soil_types=usda_soil_types) or has_sandy_soil
-
-
-_SOIL_CATEGORY_DECISION_TREE = {
-    IpccSoilCategory.ORGANIC_SOILS: _check_soil_category,
-    IpccSoilCategory.SANDY_SOILS: _check_sandy_soil_category,
-    IpccSoilCategory.WETLAND_SOILS: _check_soil_category,
-    IpccSoilCategory.VOLCANIC_SOILS: _check_soil_category,
-    IpccSoilCategory.SPODIC_SOILS: _check_soil_category,
-    IpccSoilCategory.HIGH_ACTIVITY_CLAY_SOILS: _check_soil_category,
-    IpccSoilCategory.LOW_ACTIVITY_CLAY_SOILS: _check_soil_category
-}
+_SOIL_CATEGORY_DECISION_TREE = [
+    IpccSoilCategory.ORGANIC_SOILS,
+    IpccSoilCategory.SANDY_SOILS,
+    IpccSoilCategory.WETLAND_SOILS,
+    IpccSoilCategory.VOLCANIC_SOILS,
+    IpccSoilCategory.SPODIC_SOILS,
+    IpccSoilCategory.HIGH_ACTIVITY_CLAY_SOILS,
+    IpccSoilCategory.LOW_ACTIVITY_CLAY_SOILS
+]
 """
-A decision tree mapping IPCC soil categories to corresponding check functions.
-
-Key: IpccSoilCategory
-Value: Corresponding function for checking the match of the given soil category based on soil types.
+A decision tree determining the order to check IPCC soil categories.
 """
 
 
@@ -1102,7 +1192,7 @@ def _assign_ipcc_land_use_category(
     return next(
         (
             key for key in DECISION_TREE
-            if DECISION_TREE[key](
+            if _check_ipcc_land_use_category(
                 key=key,
                 land_cover_nodes=land_cover_nodes,
                 has_long_fallow=has_long_fallow,
@@ -1183,7 +1273,7 @@ def _check_ipcc_land_use_category(*, key: IpccLandUseCategory, land_cover_nodes:
     bool
         `True` if the conditions match the specified land use category, `False` otherwise.
     """
-    LOOKUP = _LOOKUPS["landCover"][0]
+    LOOKUP = LOOKUPS["landCover"][0]
     target_lookup_values = IPCC_LAND_USE_CATEGORY_TO_LAND_COVER_LOOKUP_VALUE.get(key, None)
     valid_lookup = cumulative_nodes_lookup_match(
         land_cover_nodes,
@@ -1218,23 +1308,19 @@ Keyword arguments that can override the `landCover` lookup match for specific `I
 """
 
 
-_LAND_USE_CATEGORY_DECISION_TREE = {
-    IpccLandUseCategory.GRASSLAND: _check_ipcc_land_use_category,
-    IpccLandUseCategory.SET_ASIDE: _check_ipcc_land_use_category,
-    IpccLandUseCategory.PERENNIAL_CROPS: _check_ipcc_land_use_category,
-    IpccLandUseCategory.PADDY_RICE_CULTIVATION: _check_ipcc_land_use_category,
-    IpccLandUseCategory.ANNUAL_CROPS_WET: _check_ipcc_land_use_category,
-    IpccLandUseCategory.ANNUAL_CROPS: _check_ipcc_land_use_category,
-    IpccLandUseCategory.FOREST: _check_ipcc_land_use_category,
-    IpccLandUseCategory.NATIVE: _check_ipcc_land_use_category,
-    IpccLandUseCategory.OTHER: _check_ipcc_land_use_category
-}
+_LAND_USE_CATEGORY_DECISION_TREE = [
+    IpccLandUseCategory.GRASSLAND,
+    IpccLandUseCategory.SET_ASIDE,
+    IpccLandUseCategory.PERENNIAL_CROPS,
+    IpccLandUseCategory.PADDY_RICE_CULTIVATION,
+    IpccLandUseCategory.ANNUAL_CROPS_WET,
+    IpccLandUseCategory.ANNUAL_CROPS,
+    IpccLandUseCategory.FOREST,
+    IpccLandUseCategory.NATIVE,
+    IpccLandUseCategory.OTHER
+]
 """
-A decision tree mapping IPCC soil categories to corresponding check functions.
-
-Key: IpccLandUseCategory
-Value: Corresponding function for checking the match of the given land use category based on land cover nodes
-and additional kwargs.
+A decision tree determining the order to check IPCC land use categories.
 """
 
 
@@ -1261,7 +1347,7 @@ def _assign_ipcc_management_category(
         ipcc_land_use_category, IpccManagementCategory.NOT_RELEVANT
     )
 
-    land_cover_nodes = filter_list_term_type(management_nodes, [TermTermType.LANDCOVER])
+    land_cover_nodes = filter_list_term_type(management_nodes, [TermTermType.PASTUREMANAGEMENT])
     tillage_nodes = filter_list_term_type(management_nodes, [TermTermType.TILLAGE])
 
     should_run_ = any([
@@ -1340,7 +1426,7 @@ def _check_tillage_ipcc_management_category(
     bool
         `True` if the conditions match the specified management category, `False` otherwise.
     """
-    LOOKUP = _LOOKUPS["tillage"]
+    LOOKUP = LOOKUPS["tillage"]
     target_lookup_values = IPCC_MANAGEMENT_CATEGORY_TO_TILLAGE_MANAGEMENT_LOOKUP_VALUE.get(key, None)
     return cumulative_nodes_lookup_match(
         tillage_nodes,
@@ -1798,9 +1884,9 @@ def _get_carbon_input_kwargs(
         The carbon input keyword arguments.
     """
 
-    PRACTICE_INCREASING_C_INPUT_LOOKUP = _LOOKUPS["landUseManagement"]
-    LOW_RESIDUE_PRODUCING_CROP_LOOKUP = _LOOKUPS["landCover"][1]
-    N_FIXING_CROP_LOOKUP = _LOOKUPS["landCover"][2]
+    PRACTICE_INCREASING_C_INPUT_LOOKUP = LOOKUPS["landUseManagement"]
+    LOW_RESIDUE_PRODUCING_CROP_LOOKUP = LOOKUPS["landCover"][1]
+    N_FIXING_CROP_LOOKUP = LOOKUPS["landCover"][2]
 
     # To prevent double counting already explicitly checked practices.
     EXCLUDED_PRACTICE_TERM_IDS = {
