@@ -23,15 +23,9 @@ LOOKUPS = {
 TERM_ID = 'damageToFreshwaterEcosystemsWaterStress'
 
 
-def _indicator(value: float):
-    indicator = _new_indicator(TERM_ID, MODEL)
-    indicator['value'] = value
-    return indicator
-
-
 def run(impact_assessment: dict):
     value = impact_country_value(MODEL, TERM_ID, impact_assessment, f"{list(LOOKUPS.keys())[0]}.csv", 'allEffects')
     logRequirements(impact_assessment, model=MODEL, term=TERM_ID,
                     value=value)
     logShouldRun(impact_assessment, MODEL, TERM_ID, value is not None)
-    return None if value is None else _indicator(value)
+    return _new_indicator(term=TERM_ID, model=MODEL, value=value)
