@@ -22,12 +22,6 @@ LOOKUPS = {
 TERM_ID = 'damageToHumanHealthHumanToxicityNonCancerogenic'
 
 
-def _indicator(value: float):
-    indicator = _new_indicator(TERM_ID, MODEL)
-    indicator['value'] = value
-    return indicator
-
-
 def run(impact_assessment: dict):
     value = impact_lookup_value(MODEL, TERM_ID, impact_assessment, LOOKUPS['pesticideAI'])
-    return _indicator(value) if value is not None else None
+    return _new_indicator(term=TERM_ID, model=MODEL, value=value)
