@@ -21,17 +21,11 @@ RETURNS = {
 TERM_ID = 'nurseryDuration'
 
 
-def _practice(value: float):
-    practice = _new_practice(TERM_ID, MODEL)
-    practice['value'] = [value]
-    return practice
-
-
 def _get_value(product: dict):
     term_id = product.get('term', {}).get('@id', '')
-    return safe_parse_float(get_crop_lookup_value(MODEL, TERM_ID, term_id, LOOKUPS['crop']), None)
+    return safe_parse_float(get_crop_lookup_value(MODEL, TERM_ID, term_id, LOOKUPS['crop']), default=None)
 
 
 def run(cycle: dict):
     value = run_products_average(cycle, TERM_ID, _get_value)
-    return [_practice(value)] if value is not None else []
+    return [_new_practice(term=TERM_ID, model=MODEL, value=value)] if value is not None else []
