@@ -22,12 +22,6 @@ RETURNS = {
 TERM_ID = 'rotationDuration'
 
 
-def _practice(value: float):
-    practice = _new_practice(TERM_ID, MODEL)
-    practice['value'] = [value]
-    return practice
-
-
 def _get_value(cycle: dict):
     def get(product: dict):
         plantationLifespan = get_plantationLifespan(product)
@@ -45,4 +39,4 @@ def _get_value(cycle: dict):
 
 def run(cycle: dict):
     value = run_products_average(cycle, TERM_ID, _get_value(cycle))
-    return [_practice(value)] if value is not None else []
+    return [_new_practice(term=TERM_ID, model=MODEL, value=value)] if value is not None else []
