@@ -27,12 +27,6 @@ RETURNS = {
 TERM_ID = 'saplingsDepreciatedAmountPerCycle'
 
 
-def _input(value: float):
-    input = _new_input(TERM_ID, MODEL)
-    input['value'] = [value]
-    return input
-
-
 def _get_value(product: dict):
     term_id = product.get('term', {}).get('@id', '')
     return safe_parse_float(get_crop_lookup_value(MODEL, TERM_ID, term_id, LOOKUPS['crop']), default=None)
@@ -40,7 +34,7 @@ def _get_value(product: dict):
 
 def _run(product: dict, plantationLifespan: float, cycleDuration: float):
     value = _get_value(product)
-    return [_input(value / plantationLifespan * cycleDuration)]
+    return [_new_input(term=TERM_ID, model=MODEL, value=value / plantationLifespan * cycleDuration)]
 
 
 def _should_run_product(product: dict): return _get_value(product) is not None
