@@ -51,8 +51,7 @@ TIER = EmissionMethodTier.TIER_1.value
 
 
 def _emission(value: float):
-    emission = _new_emission(TERM_ID, MODEL)
-    emission['value'] = [value]
+    emission = _new_emission(term=TERM_ID, model=MODEL, value=value)
     emission['methodTier'] = TIER
     return emission
 
@@ -80,7 +79,7 @@ def _should_run(cycle: dict):
     measurements = site.get('measurements', [])
 
     def _get_measurement_content(term_id: str):
-        return most_relevant_measurement_value(measurements, term_id, end_date)
+        return most_relevant_measurement_value(measurements, term_id, end_date, default=None)
 
     nla_environment = _get_measurement_content('nutrientLossToAquaticEnvironment')
     soil_phosphorus_content = _get_measurement_content('totalPhosphorusPerKgSoil')
@@ -91,6 +90,7 @@ def _should_run(cycle: dict):
 
     precipitation = _get_measurement_content('precipitationAnnual')
     inputs_water = get_water_input(cycle)
+    total_water = list_sum([(inputs_water or 0)/10, precipitation or 0])
 
     practice_factor = get_practice_factor(TERM_ID, site)
     pcorr = get_pcorr(slope / 100) if slope is not None else None
@@ -100,7 +100,7 @@ def _should_run(cycle: dict):
     list_of_contents_for_A = [
         practice_factor, erodibility, slope_length,
         pcorr, p_ef_c1, ef_p_c2]
-    list_of_contents_for_R = [heavy_winter_precipitation, list_sum([(inputs_water or 0)/10, precipitation or 0])]
+    list_of_contents_for_R = [heavy_winter_precipitation, total_water]
     list_of_contents_for_value = [nla_environment, soil_phosphorus_content]
 
     logRequirements(cycle, model=MODEL, term=TERM_ID,
@@ -118,8 +118,9 @@ def _should_run(cycle: dict):
                     soil_phosphorus_content=soil_phosphorus_content)
 
     should_run = all([
+        heavy_winter_precipitation is not None,
+        total_water > 0,
         all(list_of_contents_for_A),
-        all(list_of_contents_for_R),
         all(list_of_contents_for_value)
     ])
     logShouldRun(cycle, MODEL, TERM_ID, should_run, methodTier=TIER)
