@@ -43,25 +43,26 @@ def get_pcorr(slope: float):
 
 
 def _get_C2_factor(term_id: str, term: dict):
-    return safe_parse_float(get_lookup_value(term, 'C2_FACTORS', model=MODEL, term=term_id), None)
+    return safe_parse_float(get_lookup_value(term, 'C2_FACTORS', model=MODEL, term=term_id), default=None)
 
 
 def get_practice_factor(term_id: str, site: dict):
     return safe_parse_float(
-        get_lookup_value(site.get('country', {}), 'Practice_Factor', model=MODEL, term=term_id), None)
+        get_lookup_value(site.get('country', {}), 'Practice_Factor', model=MODEL, term=term_id), default=None)
 
 
 def get_p_ef_c1(term_id: str, cycle: dict):
     primary_product = find_primary_product(cycle) or {}
     return safe_parse_float(
-        get_lookup_value(primary_product.get('term', {}), 'P_EF_C1', model=MODEL, term=term_id), None)
+        get_lookup_value(primary_product.get('term', {}), 'P_EF_C1', model=MODEL, term=term_id), default=None)
 
 
 def get_ef_p_c2(term_id: str, cycle: dict):
     tillage = _get_tillage(cycle)
     country = cycle.get('site', {}).get('country', {})
     return _get_C2_factor(term_id, tillage) if tillage else safe_parse_float(
-        get_lookup_value(country, 'EF_P_C2', model=MODEL, term=term_id), None)
+        get_lookup_value(country, 'EF_P_C2', model=MODEL, term=term_id), default=None
+    )
 
 
 def get_water_input(cycle: dict):
