@@ -25,8 +25,7 @@ TIER = EmissionMethodTier.TIER_1.value
 
 
 def _emission(value: float):
-    emission = _new_emission(TERM_ID, MODEL)
-    emission['value'] = [value]
+    emission = _new_emission(term=TERM_ID, model=MODEL, value=value)
     emission['methodTier'] = TIER
     return emission
 
