@@ -10,9 +10,9 @@ from . import MODEL
 def get_waste_values(term_id: str, cycle: dict, lookup_col: str):
     products = filter_list_term_type(cycle.get('products', []), TermTermType.WASTE)
     value = all_factor_value(
-        logs_model=MODEL,
-        logs_term_id=term_id,
-        node=cycle,
+        log_model=MODEL,
+        log_term_id=term_id,
+        log_node=cycle,
         lookup_name=f"{TermTermType.WASTE.value}.csv",
         lookup_col=lookup_col,
         blank_nodes=products,
