@@ -8,11 +8,13 @@ import datetime
 from functools import reduce
 import operator
 from pydash.objects import get
-from typing import Union, List, Callable
-from hestia_earth.schema import SchemaType
+from typing import Union, List, Callable, Any, Optional
+from hestia_earth.schema import SchemaType, TermTermType
 from hestia_earth.utils.api import download_hestia
-from hestia_earth.utils.tools import flatten, non_empty_list
+from hestia_earth.utils.tools import flatten, non_empty_list, safe_parse_date, to_precision, is_number
 from hestia_earth.utils.date import is_in_days, is_in_months
+from hestia_earth.utils.model import linked_node
+from hestia_earth.utils.term import download_term
 
 from .constant import Units
 
@@ -22,8 +24,9 @@ CACHE_KEY = '_cache'
 
 
 def cached_value(node: dict, key: str = None, default=None):
-    cache = node.get(CACHE_KEY, {})
-    return cache.get(key, default) if key else cache
+    cache = node.get(CACHE_KEY) or {}
+    value = cache.get(key) if key else cache
+    return default if value is None else value
 
 
 def group_by(values: list, keys: list):
@@ -34,15 +37,35 @@ def group_by(values: list, keys: list):
     return reduce(_group_by, values, {})
 
 
+def value_with_precision(value):
+    def _to_precision(value):
+        return to_precision(value) if is_number(value) and value else value
+
+    return list(map(_to_precision, value)) if isinstance(value, list) else _to_precision(value)
+
+
+def set_node_value(key: str, value: Any, is_list: bool = False):
+    return ({
+        key: ([
+            value_with_precision(value)
+        ] if is_list and not isinstance(value, list) else value_with_precision(value))
+    } if value is not None else {})
+
+
+def set_node_stats(node: dict):
+    include_stats = any([key in node for key in ['min', 'max', 'sd']])
+    return ({'statsDefinition': 'modelled'} if include_stats else {}) | node
+
+
+def set_node_term(key: str, term_id: str, term_type: Optional[TermTermType] = None):
+    return {
+        key: linked_node(download_term(term_id, term_type))
+    } if term_id else {}
+
+
 def _term_id(term): return term.get('@id') if isinstance(term, dict) else term
 
 
-def _omit(values: dict, keys: list) -> dict: return {k: v for k, v in values.items() if k not in keys}
-
-
-def _include(value: dict, keys: list) -> dict: return {k: v for k, v in value.items() if k in keys}
-
-
 def _run_in_serie(data: dict, models: list): return reduce(lambda prev, model: model(prev), models, data)
 
 
@@ -95,6 +118,10 @@ def multiply_values(values: list):
     return reduce(operator.mul, filtered_values, 1) if len(filtered_values) > 1 else None
 
 
+def clamp(value: Union[int, float], min_value: Union[int, float], max_value: Union[int, float]):
+    return min(max_value, max(min_value, value))
+
+
 def _numeric_weighted_average(values: list):
     total_weight = sum(Decimal(str(weight)) for _v, weight in values) if values else Decimal(0)
     weighted_values = [Decimal(str(value)) * Decimal(str(weight)) for value, weight in values]
@@ -157,6 +184,15 @@ def current_date(): return datetime.datetime.now().date().strftime('%Y-%m-%d')
 def current_year(): return int(current_date()[:4])
 
 
+def max_date(date_str: str):
+    """
+    If the date is after today, returns today. Otherwise returns the date.
+    """
+    date = safe_parse_date(date_str).date()
+    max_date = datetime.datetime.now().date()
+    return current_date() if date > max_date else date_str
+
+
 def flatten_args(args) -> list:
     """
     Flatten the input args into a single list.
