@@ -1,7 +1,6 @@
 from typing import Union
 from hestia_earth.schema import Completeness, TermTermType
-
-from .term import download_term
+from hestia_earth.utils.term import download_term
 
 completeness_fields = Completeness().required
 
