@@ -1,20 +1,37 @@
+from typing import Union, Optional, List
 from hestia_earth.schema import SchemaType, TermTermType
 from hestia_earth.utils.model import find_term_match, linked_node, filter_list_term_type
 from hestia_earth.utils.tools import list_sum, non_empty_list, list_average, flatten
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
+from hestia_earth.utils.term import download_term
 
 from hestia_earth.models.log import logger
-from . import _filter_list_term_unit, _load_calculated_node
+from . import (
+    _filter_list_term_unit, _load_calculated_node, group_by, set_node_value, set_node_stats
+)
 from .constant import Units
 from .blank_node import get_total_value, get_total_value_converted, get_lookup_value
-from .term import download_term
 from .method import include_model
 
 
-def _new_input(term, model=None):
-    node = {'@type': SchemaType.INPUT.value}
-    node['term'] = linked_node(term if isinstance(term, dict) else download_term(term))
-    return include_model(node, model)
+def _new_input(
+    term: Union[dict, str],
+    value: List[Optional[float]] = None,
+    sd: float = None,
+    min: float = None,
+    max: float = None,
+    model: Optional[Union[dict, str]] = None,
+):
+    return set_node_stats(
+        include_model({
+            '@type': SchemaType.INPUT.value,
+            'term': linked_node(term if isinstance(term, dict) else download_term(term))
+        }, model) |
+        set_node_value('value', value, is_list=True) |
+        (set_node_value('sd', sd, is_list=True) if sd is not None else {}) |
+        set_node_value('min', min, is_list=True) |
+        set_node_value('max', max, is_list=True)
+    )
 
 
 def load_impacts(inputs: list):
@@ -148,3 +165,36 @@ def total_excreta(inputs: list, units=Units.KG_N):
 def get_total_irrigation_m3(cycle: dict):
     irrigation_inputs = filter_list_term_type(cycle.get('inputs', []), TermTermType.WATER)
     return sum([list_average(i.get('value')) for i in irrigation_inputs if len(i.get('value', [])) > 0])
+
+
+def _group_inputs(inputs: list):
+    grouped_inputs = group_by(inputs, ['input.term.@id'])
+    return [
+        inputs[0] | {'value': list_sum(flatten([v.get('input-value') for v in inputs]))}
+        for inputs in grouped_inputs.values()
+    ]
+
+
+def _input_data(input: dict):
+    return {
+        'input': input,
+        'input-value': list_sum(input.get('value'), default=None),
+        'has-linked-impact-assessment': bool(input.get('impactAssessment')),
+        'is-fromCycle': input.get('fromCycle', False),
+        'is-producedInCycle': input.get('producedInCycle', False)
+    }
+
+
+def unique_background_inputs(cycle: dict):
+    inputs = non_empty_list(map(_input_data, cycle.get('inputs', [])))
+
+    # sum up inputs with the same id
+    return _group_inputs([
+        v for v in inputs
+        if all([
+            v.get('input-value') or -1 > 0,
+            not v.get('has-linked-impact-assessment'),
+            not v.get('is-fromCycle'),
+            not v.get('is-producedInCycle')
+        ])
+    ])
