@@ -1,5 +1,5 @@
 from typing import Optional
-
+from functools import lru_cache
 from hestia_earth.schema import SchemaType, SiteSiteType, TermTermType
 from hestia_earth.utils.api import find_related
 from hestia_earth.utils.tools import non_empty_list, flatten, safe_parse_date
@@ -97,7 +97,8 @@ def related_cycles(site: dict, cycles_mapping: Optional[dict[str, dict]] = None)
 
 
 def related_years(site: dict):
-    return cached_value(site, CACHE_YEARS_KEY) or years_from_cycles(related_cycles(site))
+    years = cached_value(site, CACHE_YEARS_KEY) or years_from_cycles(related_cycles(site))
+    return sorted(years) if years else []
 
 
 def related_months(site: dict):
@@ -129,6 +130,7 @@ def region_factor(model: str, region_id: str, term_id: str, termType: TermTermTy
     return get_region_lookup_value(f"region-{termType.value}.csv", region_id, term_id, model=model, term=term_id)
 
 
+@lru_cache()
 def get_land_cover_term_id(site_type: str):
     land_cover_terms = get_land_cover_siteTypes()
     term = next((
