@@ -1,9 +1,5 @@
-from typing import Union
-from functools import lru_cache
-import json
 from hestia_earth.schema import SchemaType, TermTermType, SiteSiteType
-from hestia_earth.utils.storage import _load_from_storage
-from hestia_earth.utils.api import find_node, search, download_hestia
+from hestia_earth.utils.api import find_node, search
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 
 from .constant import Units
@@ -24,28 +20,6 @@ def get_lookup_value(lookup_term: dict, column: str, skip_debug: bool = False, *
     return value
 
 
-@lru_cache()
-def _load_term_file(term_type: str):
-    try:
-        filepath = f"glossary/{term_type}.json"
-        nodes = json.loads(_load_from_storage(filepath, glossary=True))
-        return {node.get('@id'): node for node in nodes}
-    except Exception as e:
-        print(e)
-        return {}
-
-
-def download_term(term: Union[str, dict], termType: Union[str, TermTermType] = None):
-    term_id = term.get('@id', term.get('id')) if isinstance(term, dict) else term
-    term_type = (
-        termType if isinstance(termType, str) else termType.value
-    ) if termType else (
-        term.get('termType') if isinstance(term, dict) else None
-    )
-    cached_nodes = _load_term_file(term_type) if term_type else {}
-    return cached_nodes.get(term_id) or download_hestia(term_id)
-
-
 def get_liquid_fuel_terms():
     """
     Find all "liquid" `fuel` terms from the Glossary:
@@ -715,7 +689,7 @@ def get_land_cover_terms():
 
     Returns
     -------
-        List of landCover terms with associated siteTypes.
+        List of landCover terms IDs.
     """
     terms = search({
         "bool": {
@@ -726,3 +700,28 @@ def get_land_cover_terms():
         },
     }, limit=LIMIT, fields=['@id'])
     return list(map(lambda n: n["@id"], terms))
+
+
+def get_ionophore_terms():
+    """
+    Find all `Ionophore` terms from the Glossary: https://hestia.earth/glossary?query=ionophore
+
+    Returns
+    -------
+        List of ionophore term IDs.
+    """
+    terms = search({
+        "bool": {
+            "must": [
+                {"match": {"@type": SchemaType.TERM.value}},
+                {"match_phrase_prefix": {"name": "ionophore"}}
+            ],
+            "should": [
+                {"match": {"termType": TermTermType.FEEDFOODADDITIVE.value}},
+                {"match": {"termType": TermTermType.VETERINARYDRUG.value}},
+
+            ],
+            "minimum_should_match": 1
+        },
+    }, limit=LIMIT, fields=['@id'])
+    return list(map(lambda n: n["@id"], terms))
