@@ -2,7 +2,8 @@ from unittest.mock import patch
 import json
 from tests.utils import fixtures_path, fake_new_emission
 
-from hestia_earth.models.emepEea2019.n2OToAirFuelCombustionDirect import MODEL, TERM_ID, run
+from hestia_earth.models.emepEea2019 import MODEL
+from hestia_earth.models.emepEea2019.n2OToAirFuelCombustionDirect import TERM_ID, run
 
 class_path = f"hestia_earth.models.{MODEL}.{TERM_ID}"
 model_utils_path = f"hestia_earth.models.{MODEL}.utils"
