@@ -5,7 +5,7 @@ from pytest import mark
 
 from hestia_earth.models.environmentalFootprintV3_1 import MODEL_FOLDER
 from hestia_earth.models.environmentalFootprintV3_1.soilQualityIndexLandTransformation import (
-    MODEL, TERM_ID, run, _should_run
+    TERM_ID, run, _should_run
 )
 from tests.utils import fixtures_path, fake_new_indicator
 
@@ -13,12 +13,6 @@ class_path = f"hestia_earth.models.{MODEL_FOLDER}.{TERM_ID}"
 fixtures_folder = f"{fixtures_path}/{MODEL_FOLDER}/{TERM_ID}"
 
 
-def fake_rounded_indicator(value: float):
-    indicator = fake_new_indicator(TERM_ID, MODEL)
-    indicator['value'] = round(value, 7)
-    return indicator
-
-
 crop_land = {"@id": "cropland", "termType": "landCover"}
 sea_land_cover = {"@id": "seaOrOcean", "termType": "landCover"}
 forest = {"@id": "forest", "termType": "landCover"}
@@ -179,16 +173,12 @@ def test_run_italy(*args):
     ids=["No country/region => default to region world",
          "region-europe not in the lookup file => default to region world"]
 )
-@patch(f"{class_path}._indicator", side_effect=fake_rounded_indicator)
+@patch(f"{class_path}._new_indicator", side_effect=fake_new_indicator)
 def test_run_with_country_fallback(mocked_indicator: Mock, added_data: dict):
-    """
-    When given valid sub-region or country not in the lookup file, default to country 'region-world' with value 574.56
-    """
-
     with open(f"{fixtures_folder}/multipleTransformations/impact-assessment.jsonld", encoding='utf-8') as f:
         impact = json.load(f)
 
     impact = impact | added_data
 
     value = run(impact)
-    assert value['value'] == 574.56
+    assert value['value'] == 575
