@@ -35,15 +35,17 @@ RUN_SCENARIOS = [
     ("overlapping-cycles", 4),
     ("complex-overlapping-cycles", 5),
     ("missing-measurement-dates", 3),
-    ("no-biomass-measurements", 1),               # Closes issue #700
-    ("non-consecutive-biomass-measurements", 1),  # Closes issue #827
-    ("multiple-method-classifications", 5),       # Closes issue #764
-    ("non-soil-based-gohac-system", 3),           # Closes issue #848
-    ("soil-based-gohac-system", 3),               # Closes issue #848
-    ("with-gapfilled-start-date-end-date", 1),    # Closes issue #972
-    ("forest-to-orchard-with-ground-cover", 3),   # Closes issue #989
-    ("orchard-data-complete", 3),                 # Closes issue #1011
-    ("orchard-data-partially-complete", 3)        # Closes issue #1011
+    ("no-biomass-measurements", 1),               # Closes #700
+    ("non-consecutive-biomass-measurements", 1),  # Closes #827
+    ("multiple-method-classifications", 5),       # Closes #764
+    ("non-soil-based-gohac-system", 3),           # Closes #848
+    ("soil-based-gohac-system", 3),               # Closes #848
+    ("with-gapfilled-start-date-end-date", 1),    # Closes #972
+    ("forest-to-orchard-with-ground-cover", 3),   # Closes #989
+    ("orchard-data-complete", 3),                 # Closes #1011
+    ("orchard-data-partially-complete", 3),       # Closes #1011
+    ("no-measurements-data-complete", 1),         # Closes #1227
+    ("no-measurements-data-incomplete", 1)        # Closes #1227
 ]
 """List of (subfolder: str, num_cycles: int)."""
 
@@ -61,13 +63,11 @@ RUN_IDS = [f"{param[0]}, cycle{param[2]}" for param in RUN_PARAMS]
 @mark.parametrize("subfolder, num_cycles, cycle_index", RUN_PARAMS, ids=RUN_IDS)
 @patch(f"{class_path}._new_emission", side_effect=fake_new_emission)
 @patch(f"{utils_path}.related_cycles")
-@patch(f"{utils_path}._get_site")
 @patch(f"{biomass_utils_path}.get_cover_crop_property_terms", return_value=COVER_CROP_PROPERTY_TERM_IDS)
 @patch(f"{term_path}.search")
 def test_run(
     search_mock: MagicMock,
     get_cover_crop_property_terms_mock: MagicMock,
-    get_site_mock: MagicMock,
     related_cycles_mock: MagicMock,
     _new_emission_mock: MagicMock,
     subfolder: str,
@@ -85,7 +85,7 @@ def test_run(
         _load_fixture(f"{fixtures_folder}/{subfolder}/cycle{i}.jsonld") for i in range(num_cycles)
     ]
 
-    get_site_mock.return_value = site
+    cycle["site"] = site
     related_cycles_mock.return_value = cycles
 
     result = run(cycle)
@@ -97,13 +97,11 @@ def test_run(
 
 @patch(f"{class_path}._new_emission", side_effect=fake_new_emission)
 @patch(f"{utils_path}.related_cycles")
-@patch(f"{utils_path}._get_site")
 @patch(f"{biomass_utils_path}.get_cover_crop_property_terms", return_value=COVER_CROP_PROPERTY_TERM_IDS)
 @patch(f"{term_path}.search")
 def test_run_empty(
     search_mock: MagicMock,
     get_cover_crop_property_terms_mock: MagicMock,
-    get_site_mock: MagicMock,
     related_cycles_mock: MagicMock,
     _new_emission_mock: MagicMock
 ):
@@ -113,7 +111,6 @@ def test_run_empty(
     CYCLE = {}
     EXPECTED = []
 
-    get_site_mock.return_value = {}
     related_cycles_mock.return_value = [CYCLE]
 
     result = run(CYCLE)
