@@ -136,7 +136,7 @@ def test_assign_ipcc_soil_category(subfolder: str, expected: IpccSoilCategory):
     with open(f"{folder}/site.jsonld", encoding='utf-8') as f:
         site = json.load(f)
 
-    result = _assign_ipcc_soil_category(site.get("measurements", []))
+    result, *_ = _assign_ipcc_soil_category(site.get("measurements", []))
     assert result == expected
 
 
