@@ -10,15 +10,17 @@ class_path = 'hestia_earth.models.utils.indicator'
 @patch(f"{class_path}.download_term", return_value=TERM)
 def test_new_indicator(*args):
     # with a Term as string
-    indicator = _new_indicator('term')
+    indicator = _new_indicator('term', value=0)
     assert indicator == {
         '@type': 'Indicator',
-        'term': TERM
+        'term': TERM,
+        'value': 0
     }
 
     # with a Term as dict
-    indicator = _new_indicator(TERM)
+    indicator = _new_indicator(TERM, value=0)
     assert indicator == {
         '@type': 'Indicator',
-        'term': TERM
+        'term': TERM,
+        'value': 0
     }
